@@ -36,8 +36,11 @@ class Missing:
         f.close()
                 
 def main():
-    filename = sys.argv[1]
-    obj = Missing(filename)
-    obj.impute()
+	try:
+		filename = sys.argv[1]
+    	obj = Missing(filename)
+    	obj.impute()
+    except:
+    	print("Exception occurred")
 if __name__=="__main__":
     main()
\ No newline at end of file
